import React, { useRef } from "react";
import { getTaOrder } from "@/services/taOrder";
import moment from "moment";
import Page from '@/components/Page';
import { ProTable } from '@ant-design/pro-components';
import { queryTable, queryDict } from "@/utils/request";
import { getSysUser } from "@/services/sysUser";
import { getTaMemberCard } from "@/services/taMemberCard";



const TaSysUserList = queryDict(getSysUser, { labelKey: "userName", valueKey: "createdBy" });
export default (props) => {

  const TaMemberCardPhone = queryDict(getTaMemberCard, { labelKey: "memberPhone", valueKey: "cardId" });

  const TaMemberCardLeftAmount = queryDict(getTaMemberCard, { labelKey: "leftAmount", valueKey: "cardId" });

  const actionRef = useRef();
  const TaOrderList = queryTable(getTaOrder);

  const columns = [
    {
      title: "会员名称",
      dataIndex: "memberName",
    },
    {
      title: "手机号",
      dataIndex: "memberCardId",
      valueType: "select",
      request: TaMemberCardPhone,
      search: false,
    },
    {
      title: '套餐名称',
      dataIndex: "taPackageName",
      search: false,
    },
    {
      title: '套餐类型',
      dataIndex: "taPackageLimitUnit",
      valueType: 'select',
      search: false,
      valueEnum: {
        'year': '年卡',
        'month': '月卡',
        'day': '日卡',
        'order': '次卡'
      }
    },
    // {
    //   title: "总数次数",
    //   dataIndex: "totalAmount",
    //   search: false
    // },
    // {
    //   title: "剩余次数",
    //   dataIndex: "memberCardId",
    //   valueType: "select",
    //   request: TaMemberCardLeftAmount,
    //   search: false
    // },
    {
      title: "核销日期",
      dataIndex: "createdAt",
      render: (it) => (it == '-' ? '-' : moment(it).format("YYYY-MM-DD HH:mm:ss")),
      search: false
    },
    {
      title: "开卡日期",
      dataIndex: "orderDate",
      render: (it) => (it == '-' ? '-' : moment(it).format("YYYY-MM-DD HH:mm:ss")),
      search: false
    },
    {
      title: "截止日期",
      dataIndex: "expireTime",
      render: (it) => (it == '-' ? '-' : moment(it).format("YYYY-MM-DD HH:mm:ss")),
      search: false
    },
    {
      title: "备注",
      dataIndex: "",
      search: false
    },
    {
      title: "操作人",
      dataIndex: "createdBy",
      valueType: "select",
      request: TaSysUserList,
      search: false,
    },
  ]

  return (
    <Page>
      <ProTable
        cardBordered
        rowKey="orderId"
        params={{ billType: 'consume' }}
        columns={columns}
        actionRef={actionRef}
        request={TaOrderList}
      />
    </Page>
  )
}