import { getTaMemberId } from "@/services/taMember";
import { Card } from "antd";
import React, { useEffect, useState, useRef } from "react";
import { useSearchParams } from "react-router-dom";
import Page from "@/components/Page";
import { ProTable } from '@ant-design/pro-components';
import MemberInfo from "./components/MemberInfo";
import MemberCardInfo from "./components/MemberCardInfo";
import moment from "moment";
import {
  BILL_CONSUME,
  BILL_REFUND,
  BILL_RECHARGE,
  BILL_WITHDRAW,
} from "@/utils/biz";
import { getTaOrder } from "@/services/taOrder";
import { getSysUser } from "@/services/sysUser";
import { queryTable, queryDict } from "@/utils/request";
import "./index.less";
// import Pages from "./components/Pages";
export default (props) => {

  const actionRef = React.useRef();

  const [params] = useSearchParams();
  const [activeTabKey, setActiveTabKey] = useState("tab1");
  const [memberList, setMemberList] = useState();
  const [memberCardId, setMemberCardId] = useState();
  const id = params.get("id");
  const tab = params.get("tab");

  const TaOrderList = queryTable(getTaOrder);

  const TaSysUserList = queryDict(getSysUser, { labelKey: "userName", valueKey: "userId" });

  useEffect(() => {
    if (id) {
      getTaMemberId(id).then((res) => {
        setMemberList(res || {});
      });
    }
  }, []);

  useEffect(() => {
    if (tab) {
      setActiveTabKey(tab);
    }
  }, [tab]);

  const tabList = [
    {
      key: "tab1",
      tab: "会员信息",
    },
    {
      key: "tab2",
      tab: "会员卡信息",
    },
  ];

  const contentList = {
    tab1: <MemberInfo memberList={memberList} />,
    tab2: <MemberCardInfo memberId={id} setMemberCardId={setMemberCardId} />,
  };

  const columns = [
    {
      title: '套餐名称',
      dataIndex: "taPackageName"
    },
    {
      title: '套餐类型',
      dataIndex: "taPackageLimitUnit",
      valueType: 'select',
      valueEnum: {
        'year': '年卡',
        'month': '月卡',
        'day': '日卡',
        'order': '次卡'
      }
    },
    {
      title: '会员名称',
      dataIndex: "memberName",
    },
    {
      title: "消费类型",
      dataIndex: "billType",
      render: (it) =>
        it == BILL_CONSUME
          ? "消费-核销"
          : it == BILL_REFUND
            ? "退款"
            : it == BILL_RECHARGE
              ? "充值-开卡"
              : it == BILL_WITHDRAW
                ? "提现"
                : "未知",
    },
    {
      title: "消费时间",
      dataIndex: "createdAt",
      render: (it) => moment(it).format("YYYY-MM-DD HH:mm:ss"),
    },
    {
      title: '操作人',
      dataIndex: "createdBy",
      valueType: "select",
      request: TaSysUserList,
    },
  ];


  return (
    <Page back>
      <Card
        className="scorll"
        tabList={tabList}
        activeTabKey={activeTabKey}
        onTabChange={setActiveTabKey}
        style={{ width: "100%", overflowY: "scroll", maxHeight: "700px", marginBottom: "24px" }}
      >
        {contentList[activeTabKey]}
      </Card>
      {
        memberCardId && (
          <Card title="消费记录" style={{ marginTop: '24px' }}>
            <ProTable
              actionRef={actionRef}
              rowKey="cardId"
              columns={columns}
              params={{ memberCardId: memberCardId }}
              options={false}
              search={false}
              request={TaOrderList}
            />
          </Card>
        )
      }
    </Page>
  );
};
