import React, { useEffect, useRef } from "react";
import { postTaPackage, putTaPackage } from "@/services/taPackage";
import {
  ProForm,
  ProFormMoney,
  ProFormSelect,
  ProFormText,
  ProFormRadio,
  ProFormDigit
} from "@ant-design/pro-components";
import { Button, Row, Col } from "antd";
import { useNavigate } from "react-router-dom";
import { UploadImage } from "@/components/Upload";
export default (props) => {
  const { id, packageList } = props;
  const formRef = useRef();

  const navigate = useNavigate();

  useEffect(() => {
    if (packageList) {
      formRef.current?.setFieldsValue(packageList);
    }
  }, [packageList]);
  const onFinish = (values) => {
    console.log(values);
    if (!id) {
      postTaPackage({ limitType: 0, ...values }).then(() => {
        navigate(-1);
      });
    } else {
      putTaPackage(id, values).then(() => {
        navigate(-1);
      });
    }
  };

  // const onChange = (file) => {
  //   console.log('file', file);
  // };
  return (
    <ProForm
      formRef={formRef}
      onFinish={onFinish}
      layout="horizontal"
      labelCol={{ md: 2 }}
      wrapperCol={{ md: 16 }}
      submitter={{
        render: (_, doms) => [
          <Row>
            <Col offset={8}>
              <Button type="primary" htmlType="submit">
                提交
              </Button>
            </Col>
            <Col offset={1}>
              <Button onClick={() => navigate(-1)}>返回</Button>
            </Col>
          </Row>
        ],
      }}
    >
      <ProFormText name="packageName" label="套餐名称" />
      {/* <ProFormText name="packageType" label="套餐类型" /> */}
      <ProForm.Item name="thumb" label="套餐图片">
        <UploadImage />
      </ProForm.Item>
      <ProFormMoney name="charge" label="套餐价格" />
      <ProFormSelect
        name="limitUnit"
        label="套餐单位"
        options={[
          { value: "year", label: "年" },
          { value: "month", label: "月" },
          { value: "day", label: "日" },
          { value: "order", label: "次" },
        ]}
      />
      <ProFormDigit name="limitNum" label="套餐数目" placeholder="请输入年、月、日卡时长或次卡次数" />
      <ProFormText name="desc" label="套餐说明" />
      {/* <ProFormRadio.Group
        name="limitType"
        label="是否限制型消费"
        options={[
          { label: "是", value: 1 },
          { label: "否", value: 0 },
        ]}
      /> */}
      <ProFormRadio.Group
        name="status"
        label="套餐状态"
        options={[
          { label: "上架", value: 1 },
          { label: "下架", value: 0 },
        ]}
      />
    </ProForm>
  );
};
