import React, { useEffect, useState } from "react";
import { ProTable } from "@ant-design/pro-components";
import { getTaMemberCard } from "@/services/taMemberCard";
import { getTaPackage } from "@/services/taPackage";
import { queryTable, queryDict } from "@/utils/request";
import Page from '@/components/Page';
import { getSysUser } from "@/services/sysUser";
import moment from "moment";

const PackageNameList = queryDict(getTaPackage, { labelKey: "packageName", valueKey: "packageId" });

const TaSysUserList = queryDict(getSysUser, { labelKey: "userName", valueKey: "createdBy" });
export default (props) => {
  const actionRef = React.useRef();

  const TaMemberCardList = queryTable(getTaMemberCard);


  const columns = [
    {
      title: "会员名称",
      dataIndex: "memberName",
    },
    {
      title: "手机号",
      dataIndex: "memberPhone",
    },
    {
      title: "开卡人",
      dataIndex: "createdBy",
      valueType: 'select',
      request: TaSysUserList,
      search: false
    },
    {
      title: "套餐名称",
      dataIndex: "packageId",
      valueType: 'select',
      request: PackageNameList,
      ellipsis: true,
      search: false
    },
    {
      title: "套餐类型",
      dataIndex: "timeUnit",
      valueType: 'select',
      valueEnum: {
        'year': '年卡',
        'month': '月卡',
        'day': '日卡',
        'order': '次卡'
      },
      search: false
    },
    {
      title: "总次数",
      dataIndex: "totalAmount",
      render: (_, it) => it.timeUnit == 'order' ? _ : '-',
      search: false
    },
    {
      title: "剩余次数",
      dataIndex: "leftAmount",
      render: (_, it) => it.timeUnit == 'order' ? _ : '-',
      search: false
    },
    {
      title: "开卡日期",
      dataIndex: "bizDate",
      render: (_, record) => {
        const bDate = record.bizDate;

        return bDate ? moment(bDate).format("YYYY-MM-DD HH:mm:ss") : "-";
      },
      search: false
    },
    {
      title: "总时长",
      dataIndex: "totalTime",
      search: false
    },
    {
      title: "截止日期",
      dataIndex: "expireTime",
      render: (_, record) => {
        const eTime = record.expireTime;
        return eTime ? moment(eTime).format("YYYY-MM-DD HH:mm:ss") : "-";
      },
      search: false
    }
  ];

  return (
    <Page>
      <ProTable
        cardBordered
        actionRef={actionRef}
        rowKey="cardId"
        columns={columns}
        request={TaMemberCardList}
      />
    </Page>
  );
};
